<template>
  <inner-layout :cart_data="cart_data" :loading="loading">
    <template #order_confirmation>
      <div v-if="(cart_data != null && cart_data != '') && (cart_data.tag_name == null || cart_data.tag_name == '')">
        <div class="row">
          <div class="col-12">
            <div class="success_div">
                        <span class="material-icons-outlined">check_circle</span>
                        <div class="thanks_cont">
                            <h3>Success! Your order has been placed.</h3>
                            <p>We have sent you a confirmation email with your order details and one of our team will be in touch by phone - Customer service is not a department... it's an attitude!</p>
                        </div>
                    </div>

          </div>
        </div>
      </div>
      <div v-else>
        <div class="row">
          <div class="col-12  text-center">
            <div class="success_div">
                        <span class="material-icons-outlined">check_circle</span>
                        <div class="thanks_cont">
                            <h3>Success! Your order has been placed.</h3>
                            <p>We have sent you a confirmation email with your order details and one of our team will be in touch by phone - Customer service is not a department... it's an attitude!</p>
                        </div>
                    </div>
          </div>
        </div>
      </div>
      <div>
        <div>
          <order-list :cart_data="cart_data" :show_actions="false"></order-list>
          <order-total :cart_data="cart_data" :move_to_checkout="false"></order-total>
        </div>

      </div>

    </template>
    <template #alert_block>
      <location-confirmation ref="alertMsg" width="600" :confirm_button_color="'#FFFF00'" :cancel_button_color="'grey'"
        :show_close="false"
        msg="Some Products not available in your location <br>Please remove that items to confirm your order"
        @confirm="closeAlertModel()"></location-confirmation>
    </template>
  </inner-layout>
</template>
<script>
import { cloneDeep } from 'lodash';
import OrderList from '~/components/front-end/cart-component/order-list.vue';
import LocationConfirmation from '~/components/front-end/LocationConfirmation.vue';
export default {
  components: { InnerLayout: () => import('~/layouts/cart/order-confirmation.vue'), OrderList, OrderTotal: () => import('~/components/front-end/cart-component/order-total.vue'), LocationConfirmation },
  data() {
    return {
      cart_data: cloneDeep(this.$store.state.front_end_data.confirmed_order_data),
      location: this.$store.state.front_end_data.location,
      domain_id: this.$store.state.front_end_data.domain_id,
      loading: false,
      domain: this.$store.state.front_end_data.domain,
    }
  },
  head() {
    return {
      title: `Order Summary - ${this.domain.name}`,
      script: [
        {
          src: '/front-end/js/google-analytics.js'
        }
      ],
      meta: [
        {
          hid: 'description',
          name: 'description',
          content: "Order Summary"
        },
        {
          hid: 'og:title',
          name: 'og:title',
          content: "Order Summary"
        },
        {
          hid: 'og:description',
          name: 'og:description',
          content: "Order Summary"
        }, {
          hid: 'og:type',
          name: 'og:type',
          content: "Website"
        },
        {
          hid: 'og:url',
          name: 'og:url',
          content: this.domain.url + this.$route.fullPath
        },
        {
          hid: 'og:url',
          name: 'og:site_name',
          content: this.domain.name
        },
        {
          hid: 'og:image',
          name: 'og:image',
          content: "/images/logo.png"
        },
        {
          hid: 'name',
          name: 'twitter:card',
          content: "summary_large_image"
        },
        {
          hid: 'name',
          name: 'twitter:title',
          content: "Order Summary"
        },
        {
          hid: 'name',
          name: 'twitter:description',
          content: "Order Summary"
        },
        {
          hid: 'name',
          name: 'twitter:image:src',
          content: "/images/logo.png"
        },
        {
          hid: 'name',
          name: 'twitter:site',
          content: this.domain.name
        },
      ],
    }
  },
  mounted() {
    this.$auth.$storage.setUniversal('confirmed_id',"");
  },
  methods: {
    closeAlertModel() {
      this.$refs.alertMsg.view = false;
    },
  }
}
</script>
